@@ -1,10 +1,8 @@
-#' @include method.R
-#' @include methodMatrix.R
+#' @include method.R methodMatrix.R
 
 #' @name interface-akmedoids
-#' @rdname interface-akmedoids
 #' @title akmedoids interface
-#' @seealso [lcMethodAkmedoids] \link[akmedoids]{akclustr}
+#' @seealso [lcMethodAkmedoids] `akmedoids::akclustr`
 #' @keywords internal
 NULL
 
@@ -17,11 +15,11 @@ setClass('lcMethodAkmedoids', contains = 'lcMatrixMethod')
 #' @inheritParams lcMethodKML
 #' @param clusterCenter A function for computing the cluster center representation.
 #' @param crit Criterion to apply for internal model selection. Not applicable.
-#' @param ... Arguments passed to [akmedoids::akclustr].
+#' @param ... Arguments passed to `akmedoids::akclustr`.
 #' The following external arguments are ignored: traj, id_field, k
 #' @examples
 #' data(latrendData)
-#' if (require("akmedoids")) {
+#' if (rlang::is_installed("akmedoids")) {
 #'   method <- lcMethodAkmedoids(response = "Y", time = "Time", id = "Id", nClusters = 3)
 #'   model <- latrend(method, data = latrendData)
 #' }
@@ -37,6 +35,7 @@ lcMethodAkmedoids = function(
   crit = 'Calinski_Harabasz', # Default silhouette width results in: Error in smooth.spline(x, y) : 'tol' must be strictly positive and finite
   ...
 ) {
+  .loadOptionalPackage('akmedoids')
   mc = match.call.all()
   mc$Class = 'lcMethodAkmedoids'
   do.call(new, as.list(mc))
@@ -46,7 +45,7 @@ lcMethodAkmedoids = function(
 setMethod('getArgumentDefaults', 'lcMethodAkmedoids', function(object) {
   c(
     formals(lcMethodAkmedoids),
-    formals(akmedoids::akclustr),
+    formals(akclustr),
     callNextMethod()
   )
 })
@@ -59,6 +58,11 @@ setMethod('getArgumentExclusions', 'lcMethodAkmedoids', function(object) {
   )
 })
 
+#' @rdname interface-akmedoids
+setMethod('getCitation', 'lcMethodAkmedoids', function(object, ...) {
+  citation('akmedoids')
+})
+
 #' @rdname interface-akmedoids
 setMethod('getName', 'lcMethodAkmedoids', function(object) 'anchored k-medoids')
 
@@ -68,14 +72,14 @@ setMethod('getShortName', 'lcMethodAkmedoids', function(object) 'akm')
 #' @rdname interface-akmedoids
 #' @inheritParams fit
 setMethod('fit', 'lcMethodAkmedoids', function(method, data, envir, verbose, ...) {
-  args = as.list(method, args = akmedoids::akclustr)
+  args = as.list(method, args = akclustr)
   args$traj = envir$dataMat
   args$k = method$nClusters
   args$id_field = FALSE
 
   assert_that(method$nClusters %between% c(3, 20), msg = 'akmedoids only supports nClusters = 3, ..., 20')
 
-  model = do.call(akmedoids::akclustr, args)
+  model = do.call(akclustr, args)
 
   clusNames = make.clusterNames(method$nClusters)
 
