@@ -10,23 +10,35 @@ setMethod('postprob', 'lcModelMixAK_GLMMlist', function(object, ...) {
 })
 
 #' @rdname interface-mixAK
-setMethod('predictForCluster', 'lcModelMixAK_GLMMlist', function(object, newdata, cluster, what = 'mu', ...) {
+setMethod('predictForCluster', 'lcModelMixAK_GLMMlist', function(
+  object, newdata, cluster, what = 'mu', ...
+) {
   models = getGLMM_MCMCs(object)
   k = match(cluster, clusterNames(object))
 
-  Reduce('+', lapply(models, .predictForCluster_GLMM_MCMC,
-                     k = k,
-                     method = getLcMethod(object),
-                     newdata = newdata, ...)) / length(models)
+  Reduce(
+    '+',
+    lapply(
+      models,
+      .predictForCluster_GLMM_MCMC,
+      k = k,
+      method = getLcMethod(object),
+      newdata = newdata,
+      ...
+    )
+  ) / length(models)
 })
 
 
+#' @exportS3Method stats::coef
 coef.lcModelMixAK_GLMMlist = function(object, ...) {
   models = getGLMM_MCMCs(object)
   Reduce('+', lapply(models, coef, ...)) / length(models)
 }
 
-deviance.lcModelMixAK_GLMMlist = function(object) {
+
+#' @exportS3Method stats::deviance
+deviance.lcModelMixAK_GLMMlist = function(object, ...) {
   models = getGLMM_MCMCs(object)
   Reduce('+', lapply(models, deviance)) / length(models)
 }
