@@ -3,8 +3,13 @@
 
 # trajectories ####
 #' @rdname trajectories
+#' @param cluster Experimental feature for data.frame input: a vector of cluster membership per id
 #' @aliases trajectories,data.frame-method
-setMethod('trajectories', 'data.frame', function(object, id, time, response, ...) {
+setMethod('trajectories', 'data.frame', function(object, id, time, response, cluster, ...) {
+  if (length(cluster) > 1 && length(cluster) == uniqueN(object[[id]])) {
+    object$Cluster = cluster[rleidv(object[[id]])]
+  }
+
   object
 })
 
@@ -68,7 +73,7 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
   )
 
   clusTrajData = as.data.table(object) %>%
-    .[, .(Value = center(get(response))), keyby = c(cluster, time)] %>%
+    .[, .(Value = center(get(..response))), keyby = c(cluster, time)] %>%
     setnames('Value', response)
 
   clusterNames = as.character(unique(clusTrajData[[cluster]]))
@@ -86,7 +91,7 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
     trajectories = trajectories[1],
     facet = facet,
     id = id,
-    rawdata = object,
+    trajData = object,
     ...
   )
 })
@@ -102,7 +107,7 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
   trajectories = FALSE,
   facet = FALSE,
   id,
-  rawdata = NULL,
+  trajData = NULL,
   ...
 ) {
   .loadOptionalPackage('ggplot2')
@@ -112,8 +117,8 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
     has_name(data, response),
     has_name(data, time),
     has_name(data, cluster),
+    is.scalar(trajectories),
     is.flag(trajectories) || is.character(trajectories),
-    length(trajectories) == 1,
     is.flag(facet)
   )
 
@@ -121,42 +126,46 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
   clusterOrderNames = make.orderedClusterNames(clusterNames, clusterOrder, subset = TRUE)
   clusterIndices = match(clusterOrderNames, clusterNames)
 
-  data = data.table(data)[get(cluster) %in% clusterOrderNames]
-  data[, c(cluster) := factor(
-    get(cluster),
-    levels = clusterNames[clusterIndices],
-    labels = clusterLabels[clusterIndices]
-  )]
+  data = data.table(data)[get(cluster) %in% clusterOrderNames] %>%
+    .[, c(cluster) := factor(
+      get(cluster),
+      levels = clusterNames[clusterIndices],
+      labels = clusterLabels[clusterIndices]
+    )]
+
+  if (!is.null(trajData)) {
+    trajData = data.table(trajData)[get(cluster) %in% clusterOrderNames] %>%
+      .[, c(cluster) := factor(
+        get(cluster),
+        levels = clusterNames[clusterIndices],
+        labels = clusterLabels[clusterIndices]
+      )]
+  }
+
 
   if (isTRUE(as.logical(trajectories))) {
     # show trajectories
     assert_that(
-      is.data.frame(rawdata),
-      nrow(rawdata) > 0,
+      is.data.frame(trajData),
+      nrow(trajData) > 0,
       !missing(id)
     )
 
     p = plotTrajectories(
-      rawdata,
+      trajData,
       response = response,
       time = time,
       id = id,
-      facet = facet,
+      facet = FALSE,
       cluster = cluster,
       ...
     )
   } else if (isFALSE(as.logical(trajectories))) {
     # don't show trajectories
     p = ggplot2::ggplot()
-    if (facet) {
-      p = p + ggplot2::facet_wrap(cluster)
-    }
   } else {
     # ribbon plot
     p = ggplot2::ggplot()
-    if (facet) {
-      p = p + ggplot2::facet_wrap(cluster)
-    }
 
     if (grepl('^[0-9]{1,2}pct$', trajectories)) {
       # percentile range
@@ -192,12 +201,20 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
     }
 
     # compute ribbon
-    ribbonData = as.data.table(rawdata)[, as.list(ribbonFun(get(response))), keyby = c(cluster, time)]
-    assert_that(ncol(ribbonData) == 4, msg = 'ribbon stat implementation error\nplease report.')
+    ribbonData = as.data.table(trajData)[, as.list(ribbonFun(get(response))), keyby = c(cluster, time)]
+    assert_that(
+      ncol(ribbonData) == 4,
+      msg = 'ribbon stat implementation error\nplease report.'
+    )
     setnames(ribbonData, c(cluster, time, 'ymin', 'ymax'))
 
     p = p + ggplot2::geom_ribbon(
-      mapping = ggplot2::aes(x = !!as.name(time), ymin = ymin, ymax = ymax),
+      mapping = ggplot2::aes(
+        x = !!as.name(time),
+        ymin = ymin,
+        ymax = ymax,
+        fill = !!.as_lang(cluster)
+      ),
       data = ribbonData,
       alpha = .5
     ) + ggplot2::labs(
@@ -209,21 +226,50 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
   }
 
   if (facet) {
-    p = p + ggplot2::guides(color = 'none')
+    # black cluster trajectories
+    p = p +
+      ggplot2::guides(color = 'none') +
+      ggplot2::geom_line(
+        mapping = ggplot2::aes(
+          x = !!.as_lang(time),
+          y = !!.as_lang(response),
+          group = !!.as_lang(cluster)
+        ),
+        data = data,
+        ...
+      )
+  } else {
+    # non-faceted plot
+    if (trajectories) {
+      # color used for trajectories, use shapes to mark cluster trajectories
+      p = p + ggplot2::geom_line(
+        mapping = ggplot2::aes(
+          x = !!.as_lang(time),
+          y = !!.as_lang(response),
+          group = !!.as_lang(cluster)
+        ),
+        data = data,
+        ...
+      )
+    } else {
+      # colored cluster trajectories
+      p = p + ggplot2::geom_line(
+        mapping = ggplot2::aes(
+          x = !!.as_lang(time),
+          y = !!.as_lang(response),
+          color = !!.as_lang(cluster)
+        ),
+        data = data,
+        ...
+      )
+    }
   }
 
-  # add cluster trajectories to plot
-  p = p + ggplot2::geom_line(
-    mapping = ggplot2::aes(
-      x = !!.as_lang(time),
-      y = !!.as_lang(response),
-      color = !!.as_lang(cluster)
-    ),
-    data = data,
-    ...
-  ) + ggplot2::labs(title = 'Cluster trajectories')
+  if (facet) {
+    p = p + ggplot2::facet_wrap(cluster)
+  }
 
-  p
+  p + ggplot2::labs(title = 'Cluster trajectories')
 }
 
 
@@ -234,8 +280,9 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
 #' @aliases plotTrajectories,data.frame-method
 #' @inheritParams trajectories
 #' @param response Response variable `character` name or a `call`.
-#' @param cluster Cluster variable name. If unspecified, trajectories are not grouped.
-#' Alternatively, cluster is a vector indicating cluster membership per id.
+#' @param cluster Whether to plot trajectories grouped by cluster (determined by the "Cluster" column).
+#' Alternatively, the name of the cluster column indicating trajectory cluster membership.
+#' If unspecified, trajectories are grouped if the object contains a "Cluster" column.
 #' @param facet Whether to facet by cluster.
 #' @seealso [trajectories] [plotFittedTrajectories] [plotClusterTrajectories]
 #' @examples
@@ -258,24 +305,14 @@ setMethod('plotClusterTrajectories', 'data.frame', function(
 #'     time = "Time",
 #'     cluster = "Class"
 #'   )
-#'
-#'   # compute cluster membership based on the mean being below 0
-#'   assignments <- aggregate(Y ~ Id, latrendData, mean)$Y < 0
-#'   plotTrajectories(
-#'     latrendData,
-#'     response = "Y",
-#'     id = "Id",
-#'     time = "Time",
-#'     cluster = assignments
-#'   )
 #' }
 setMethod('plotTrajectories', 'data.frame',
   function(
     object,
     response,
+    cluster,
     time = getOption('latrend.time'),
     id = getOption('latrend.id'),
-    cluster = NULL,
     facet = TRUE,
     ...
   ) {
@@ -286,35 +323,34 @@ setMethod('plotTrajectories', 'data.frame',
     has_name(object, id)
   )
 
-  if (missing(response)) {
-    # determine response variable
-    numMask = vapply(object, is.numeric, FUN.VALUE = TRUE)
-    dfNum = subset(object, select = setdiff(names(object)[numMask], c(id, time)))
+  if (missing(cluster)) {
+    cluster = has_name(object, 'Cluster')
+  }
 
-    counts = vapply(dfNum, uniqueN, FUN.VALUE = 0L)
-    response = names(dfNum)[which.max(counts)]
-    message(
-      sprintf(
-        'Automatically selected "%s" as the response variable.
-        To override this, specify the "response" argument.',
-        response
-      )
+  if (isTRUE(cluster)) {
+    assert_that(
+      has_name(object, 'Cluster'),
+      msg = 'cluster = TRUE but object has no "Cluster" column'
     )
+    cluster = 'Cluster'
+  }
+
+  if (missing(response)) {
+    response = .guessResponseVariable(object, id = id, time = time, cluster = cluster)
   }
 
   assert_that(
     !is.character(response) || has_name(object, response),
-    length(cluster) != 1 || (is.character(cluster) && has_name(object, cluster)),
+    is.scalar(cluster),
+    isFALSE(cluster) || is.character(cluster),
     is.flag(facet)
   )
 
-  if (length(cluster) > 1) {
-    assert_that(length(cluster) == uniqueN(object[[id]]))
-    object$Cluster = cluster[rleidv(object[[id]])]
-    cluster = 'Cluster'
+  if (is.character(cluster)) {
+    assert_that(has_name(object, cluster))
   }
 
-  if (!is.null(cluster) && !isTRUE(facet)) {
+  if (!isFALSE(cluster) && !isTRUE(facet)) {
     map = ggplot2::aes(
       x = !!.as_lang(time),
       y = !!.as_lang(response),
@@ -334,7 +370,7 @@ setMethod('plotTrajectories', 'data.frame',
     ggplot2::geom_line(mapping = map, data = object) +
     ggplot2::labs(title = 'Trajectories')
 
-  if (!is.null(cluster) && isTRUE(facet)) {
+  if (!isFALSE(cluster) && isTRUE(facet)) {
     p = p + ggplot2::facet_wrap(cluster)
   }
 
