@@ -3,10 +3,10 @@ context('transform-predict')
 model = testModel
 
 test_that('NULL', {
-  out = transformPredict(NULL, model, newdata = data.frame(Assessment = numeric()))
+  out = transformPredict(NULL, model, newdata = data.frame(time = numeric()))
   expect_true(nrow(out) == 0)
 
-  outClus = transformPredict(NULL, model, newdata = data.frame(Cluster = character(), Assessment = numeric()))
+  outClus = transformPredict(NULL, model, newdata = data.frame(Cluster = character(), time = numeric()))
   expect_true(nrow(out) == 0)
   expect_true(has_name(outClus, 'Cluster'))
 
@@ -26,16 +26,16 @@ test_that('vector', {
   out2 = transformPredict(
     1:2,
     model,
-    newdata = data.frame(Assessment = 1:2, Cluster = clusterNames(model))
+    newdata = data.frame(time = 1:2, Cluster = clusterNames(model))
   )
   expect_true(nrow(out2) == 2)
 
   # no cluster column
-  expect_error(transformPredict(1:2, model, newdata = data.frame(Assessment = 1:2)), 'Cluster')
+  expect_error(transformPredict(1:2, model, newdata = data.frame(time = 1:2)), 'Cluster')
   # wrong time column name
-  expect_error(transformPredict(1:2, model, newdata = data.frame(Time = 1:2)), 'Assessment')
+  expect_error(transformPredict(1:2, model, newdata = data.frame(Time = 1:2)), 'time')
   expect_error(transformPredict(head(vec, -1), model, newdata = newdata))
-  expect_error(transformPredict(1:2, model, newdata = data.frame(Assessment = c(1, NA))))
+  expect_error(transformPredict(1:2, model, newdata = data.frame(time = c(1, NA))))
 })
 
 test_that('matrix', {
@@ -75,9 +75,9 @@ test_that('full data.frame', {
   N = nobs(model)
 
   df = data.frame(
-    Traj = newdata$Traj,
+    id = newdata$id,
     Fit = rep(seq_len(nClusters(model)), each = N),
-    Assessment = rep(newdata$Assessment, nClusters(model)),
+    time = rep(newdata$time, nClusters(model)),
     Cluster = rep(clusterNames(model), each = N)
   )
   assert_that(nrow(df) == N * nClusters(model))
@@ -87,5 +87,5 @@ test_that('full data.frame', {
   # assumes cluster orders match
   expect_equal(out$Fit, as.integer(newdata$Cluster))
 
-  expect_error(transformPredict(subset(df, select = c('Fit', 'Assessment', 'Cluster')), model, newdata = newdata), 'Traj')
+  expect_error(transformPredict(subset(df, select = c('Fit', 'time', 'Cluster')), model, newdata = newdata), 'id')
 })
